"use strict";(self.webpackChunkomicverse_notebook=self.webpackChunkomicverse_notebook||[]).push([[329],{329(e,r,o){Object.defineProperty(r,"__esModule",{value:!0});const n=o(117);function a(e){return{safe:!0,mimeTypes:[e],defaultRank:1,createRenderer:()=>new n.OmicVerseRenderer(e)}}o(665);const t={id:"omicverse-notebook:dataframe-mime",rendererFactory:a(n.DATAFRAME_MIME_TYPE),rank:1,dataType:"json"},s={id:"omicverse-notebook:anndata-mime",rendererFactory:a(n.ANNDATA_MIME_TYPE),rank:1,dataType:"json"};r.default=[t,s]}}]);