@font-face {
    font-family: 'Fira Code';
    src: './fonts/FiraCode-Regular.ttf' format('truetype');
    font-weight: 400;
    font-style: normal;
}

@font-face {
    font-family: 'Fira Code';
    src: './fonts/FiraCode-Bold.ttf' format('truetype');
    font-weight: 700;
    font-style: normal;
}