@import './variables.css';
@import './fonts.css';
/* Set the default typography for monospace elements */
tt,
code,
kbd,
samp,
pre {
  font-family: var(--jp-code-font-family);
  font-size: var(--jp-code-font-size);
  line-height: var(--jp-code-line-height);
}